.. image:: https://github.com/cfsengineering/cpacspy/actions/workflows/python-package-conda.yml/badge.svg?branch=main
    :target: https://github.com/cfsengineering/cpacspy/actions/workflows/python-package-conda.yml
    :alt: Pytest Status


Python package to read, write and analyse CPACS AeroPerformanceMaps.

You need to have TIXI and TIGL install on your computer to use this package. 
For more information:

TIXI: https://github.com/DLR-SC/tixi

TIGL: https://github.com/DLR-SC/tigl


Install with pip
================

.. code-block:: bash

   $ pip install cpacspy


To build and install locally
============================

.. code-block:: bash

   $ cd cpacspy
   $ python -m build
   $ pip install --user .


How to use this package
=======================

To see how to use this module, check out /example/cpacspy_use.py


License
=======

**License:** Apache-2.0
